function [x0,c] = initial_set(parameters,input_data)
%% define model constants

c.f_G = 0.0056; % conversion factor glucose - convert mg to mmol (mmol/mg)
c.f_I = 0.144; % conversion factor insulin - convert pmol to mU (mU/pmol)
c.V_G = 17; % glucose distribution volume (L)
c.V_I = 13; % insulin distribution volume (L)
c.r_t = 10; % threshold for renal glucose extraction (mmol/L)
c.r_f = 0.03; % glomerular filtration rate (L/min)

%% define initial values for state variables
 
top1 = (1+exp((parameters(18)-1)./parameters(8))).*parameters(24); %top1 parameter value at time 0 [unitless]

G_Gut_0 = 0; %initial mass of glucose in gut [mg]
G_Pl_0 = input_data.glucose(1,1); %initial plasma glucose concentration from data point at time 0 [mmol/L]
Del_G_Eff_0 = top1./(1+exp((parameters(18)-(G_Pl_0./parameters(11)))./parameters(8))); %time 0 value of delayed glucose effect on IS [unitless]
I_Pl_0 = input_data.insulin(1,1); %initial plasma insulin concentration from data point at time 0 [mU/L]
Del_I_0 = I_Pl_0; %initial delayed plasma insulin concentration from data point at time 0[mU/l];

x0=[G_Gut_0,G_Pl_0,Del_G_Eff_0,I_Pl_0,Del_I_0];