clear all
close all
        
%% Determine the study

% 0 - Case points
% 1 - Christiansen et al. (1998)
% 2 - Rijkelijkhuizen et al. (2009)

study = 1;

%% Data loading

if study == 0
% no experimental data 

input_data.time=[0 30 60 90 120 150 180 210 240]; %min
input_data.glucose=4; %mmol/L
input_data.insulin=5; %mU/L
input_data.meal.G = 75000; %mg 
time=[0:0.5:240]; %min

end

if study == 1
% Christiansen et al. (1998) data

load('Christiansen_data.mat')

dataset= Christiansen;
input_data.time=dataset.glucose(1,:); %min
input_data.glucose=dataset.glucose(2,:); %mmol/L
input_data.insulin=dataset.insulin(2,:); %mU/L
input_data.meal.G = 75000; %mg 
time = [0:0.5:240]; %min

end


if study == 2
% Rijkelijkhuizen et al. (2009)

load('Rijkelijkhuizen_data.mat')

dataset= Rijkelijkhuizen.ngm; %normal glucose metabolism group
% dataset= Rijkelijkhuizen.igm; %impaired glucose metabolism group
% dataset= Rijkelijkhuizen.dm; %type-2 diabetic group
input_data.time=dataset.glucose.time'; %min
input_data.glucose=dataset.glucose.value'; %mmol/L
input_data.insulin=0.144.*dataset.insulin.value'; %unit conversion of insulin (pmol/L to mU/L)
input_data.meal.G = 75000; %mg
time = [0:0.5:240]; %min

end

%% Only simulation with given reference points

ref_set = [4 5 10 0.3]; %Gref Iref ISref Uidref
plotflux = 1; %to plot fluxes
nest = 0; %for nested figures

simulate_model(input_data,ref_set,time,nest,study,plotflux)

%% Estimation with one initial set

initial_par = [4 5 10 0.3]; %Gref Iref ISref Uidref
lb = [0 0 0 0]; %lower bound for estimation
ub = [Inf Inf Inf Inf]; %upper bound for estimation
fig_yn = 1; %to display the plot of fitting 
plotflux = 1; %to plot fluxes
nest = 0; %for nested figures

out = fit_model(initial_par,input_data,time,lb,ub,fig_yn,study,nest,plotflux);

%% Estimation with multiple initials  

initial_par = [4 5 10 0.3]; %Gref Iref ISref Uidref
lb = [0 0 0 0]; %lower bound for estimation
ub = [Inf Inf Inf Inf]; %upper bound for estimation
fig_yn = 1;
plotflux = 0;
nest = 1;
num_par_sets = 20;
noise = 0.5;

out = fit_model_multiple_initials(initial_par, input_data, time, lb, ub, fig_yn, num_par_sets, noise, study, nest, plotflux);

optimal = 1;
for i=1:num_par_sets
if out(i).resnorm<out(optimal).resnorm
   optimal = i;
end
end
optimal_par_set = out(optimal).p_opt;

%% Sensitivity Analysis
clear all
close all

factor = 1; %1 if reference points
            %2 if initial values

if factor==1
input_data.glucose(1,1)=4; %initials are fixed at healthy value
input_data.insulin(1,1)=5; %initials are fixed at healthy value

s.Gref=[4:0.1:10];     %G_ref parameter range
s.Iref=[5:0.2:15];     %I_ref parameter range
s.ISref=[0:0.2:10];    %IS_ref parameter range
s.Uidref=[0:0.01:0.3]; %Uid_ref parameter range
end  

if factor==2
input_data.glucose=[];
input_data.insulin=[];

s.input_data.glucose=[3:0.1:10]; %G_PL(0) parameter range
s.input_data.insulin=[3:0.2:15]; %I_PL(0) parameter range
end

input_data.meal.G = 75000; %mg from base run
input_data.time = [0 30 60 90 120 150 180 210 240];
time = [0:0.5:240];

ref_par=[4 5 10 0.3]; %base run values of reference points

sensitivity_analysis(factor, s, ref_par, input_data, time)
