function out = simulate_model(input_data,parameters,time,nest,study,plotflux)
%% simulate model for a given parameter set

parameters = parameter_set(parameters);

[initial_values,constants]=initial_set(parameters,input_data);

ODE_options = odeset('RelTol',1e-5);

[T,X] = ode45(@ODE_set,time,initial_values,ODE_options,parameters,constants,input_data);


%% Generate figure

if study == 2
   tick_time = [input_data.time 150 180 210 240];
else
   tick_time = [0 30 60 90 120 150 180 210 240];
end

if nest == 0
     figure()
end
 
 %plot glucose
 subplot(2,1,1)
 plot(T,X(:,2),'Color','r','LineWidth',2);
 if study == 1 || study == 2
 hold on
 plot(input_data.time,input_data.glucose(1,:),'kx','MarkerSize',10)
 end
 xlabel('min')
 ylabel('mmol/L');
 title('Plasma Glucose Concentration')
 xlim([-10,T(end)+10]);
 xticks(tick_time)
 
 %plot insulin
 subplot(2,1,2)
 plot(T,X(:,4),'Color','r','LineWidth',2);
 if study == 1 || study == 2
 hold on
 plot(input_data.time,input_data.insulin(1,:),'kx','MarkerSize',10)
 end
 xlabel('min')
 ylabel('mU/L');
 title('Plasma Insulin Concentration')
 xlim([-10,T(end)+10]);
 xticks(tick_time)
 
 if plotflux
      fluxes = ODE_flux_set(T,X,parameters,constants,input_data);

 %plot glucose fluxes
 figure()
 
 %Glucose Appearance in Gut
 plot(T,fluxes(:,1),'Color','r','LineWidth',3);
 xlabel('time (mins)')
 ylabel('mg/min');
 title('Oral Glucose Input')
 xlim([-10,T(end)+10]);
 xticks(tick_time)
 
 figure()
 %Glucose Appearance in Plasma = converted Gut Emptying
 subplot(2,2,1)
 plot(T,fluxes(:,2),'Color','r','LineWidth',2);
 xlabel('min')
 ylabel('mmol/L/min');
 title('Glucose Appearance in Plasma')
 xlim([-10,T(end)+10]);
 xticks(tick_time)
 
 %EGP
 subplot(2,2,2)
 plot(T,fluxes(:,3),'Color','r','LineWidth',2);
 xlabel('min')
 ylabel('mmol/L/min');
 title('Endogeneous Glucose Production')
 xlim([-10,T(end)+10]);
 xticks(tick_time)
 
 %Insulin Dependent Glucose Uptake
 subplot(2,2,3)
 plot(T,fluxes(:,4),'-','Color','r','LineWidth',2);
 xlabel('min')
 ylabel('mmol/L/min');
 title('Insulin Dependent Glucose Uptake')
 xlim([-10,T(end)+10]);
 xticks(tick_time)
 
 %Renal Extraction
 subplot(2,2,4)
 plot(T,fluxes(:,5),'-','Color','r','LineWidth',2);
 xlabel('min')
 ylabel('mmol/L/min');
 title('Renal Extraction')
 xlim([-10,T(end)+10]);
 xticks(tick_time)
 
 %plot insulin fluxes
    figure()
 %Insulin Secretion
 subplot(2,1,1)
 plot(T,fluxes(:,6),'-','Color','r','LineWidth',2);
 xlabel('min')
 ylabel('mU/L/min');
 title('Insulin Secretion')
 xlim([-10,T(end)+10]);
 xticks(tick_time)

 %Insulin Degradation
 subplot(2,1,2)
 plot(T,fluxes(:,7),'-','Color','r','LineWidth',2);
 xlabel('min')
 ylabel('mU/L/min');
 title('Insulin Degradation')
 xlim([-10,T(end)+10]);
 xticks(tick_time)
 
 end
